@@ -133,7 +133,7 @@ func (tree *ParserT) parseArray(exec bool) ([]rune, *primitives.DataType, error)
 				}
 
 			default:
-				_, v, _, err := tree.parseVarScalar(exec, exec, varAsValue)
+				_, v, _, err := tree.parseVarScalar(exec, varAsValue)
 				if err != nil {
 					return nil, nil, err
 				}
