@@ -136,7 +136,7 @@ func (tree *ParserT) parseStringInfix(qEnd rune, exec bool) ([]rune, error) {
 				}
 			default:
 				// inline scalar
-				scalar, v, _, err := tree.parseVarScalar(exec, exec, varAsString)
+				scalar, v, _, err := tree.parseVarScalar(exec, varAsString)
 				if err != nil {
 					return nil, err
 				}
@@ -222,7 +222,13 @@ func (tree *ParserT) parseBlockQuote() ([]rune, error) {
 
 		switch r {
 		case '#':
-			tree.parseComment()
+			if tree.prevChar() == '/' {
+				if err := tree.parseCommentMultiLine(); err != nil {
+					return nil, err
+				}
+			} else {
+				tree.parseComment()
+			}
 
 		case '\n':
 			tree.crLf()
