@@ -144,6 +144,14 @@ func delayedPreviewTimer(rl *Instance, fn PreviewFuncT, size *PreviewSizeT, item
 	var ctx context.Context
 
 	callback := func(lines []string, pos int, err error) {
+		if pos == -1 {
+			if rl.previewCache != nil && rl.previewCache.pos < len(lines) {
+				pos = rl.previewCache.pos
+			} else {
+				pos = 0
+			}
+		}
+
 		select {
 		case <-ctx.Done():
 			return
