@@ -1,13 +1,6 @@
 package main
 
-import (
-	"testing"
-
-	"github.com/lmorg/murex/test"
-	"github.com/lmorg/murex/test/count"
-)
-
-func TestGoPath(t *testing.T) {
+/*func TestGoPath(t *testing.T) {
 	count.Tests(t, 1)
 
 	pwd := goPath()
@@ -15,10 +8,10 @@ func TestGoPath(t *testing.T) {
 	if pwd == "" {
 		t.Error("$GOPATH env var appears to be unset. This is needed for wasmserver to locate which directory to serve")
 	}
-}
+}*/
 
-func TestPathBuilder(t *testing.T) {
+/*func TestPathBuilder(t *testing.T) {
 	count.Tests(t, 1)
 
 	test.Exists(t, pathBuilder()+"/index.html")
-}
+}*/
